@@ -17,13 +17,8 @@ from typing import Any, Dict, List, Type, overload
 
 from botocore.client import ClientMeta
 
-from mypy_boto3_codestar_notifications.paginator import (
-    ListEventTypesPaginator,
-    ListNotificationRulesPaginator,
-    ListTargetsPaginator,
-)
-
-from .literals import DetailType, NotificationRuleStatus
+from .literals import DetailTypeType, NotificationRuleStatusType
+from .paginator import ListEventTypesPaginator, ListNotificationRulesPaginator, ListTargetsPaginator
 from .type_defs import (
     CreateNotificationRuleResultTypeDef,
     DeleteNotificationRuleResultTypeDef,
@@ -72,7 +67,7 @@ class Exceptions:
 
 class CodeStarNotificationsClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codestar-notifications.html#CodeStarNotifications.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codestar-notifications.html#CodeStarNotifications.Client)
     [Show boto3-stubs documentation](./client.md)
     """
 
@@ -81,8 +76,8 @@ class CodeStarNotificationsClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codestar-notifications.html#CodeStarNotifications.Client.can_paginate)
-        [Show boto3-stubs documentation](./client.md#can-paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codestar-notifications.html#CodeStarNotifications.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
     def create_notification_rule(
@@ -91,32 +86,32 @@ class CodeStarNotificationsClient:
         EventTypeIds: List[str],
         Resource: str,
         Targets: List[TargetTypeDef],
-        DetailType: DetailType,
+        DetailType: DetailTypeType,
         ClientRequestToken: str = None,
         Tags: Dict[str, str] = None,
-        Status: NotificationRuleStatus = None,
+        Status: NotificationRuleStatusType = None,
     ) -> CreateNotificationRuleResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codestar-notifications.html#CodeStarNotifications.Client.create_notification_rule)
-        [Show boto3-stubs documentation](./client.md#create-notification-rule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codestar-notifications.html#CodeStarNotifications.Client.create_notification_rule)
+        [Show boto3-stubs documentation](./client.md#create_notification_rule)
         """
 
     def delete_notification_rule(self, Arn: str) -> DeleteNotificationRuleResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codestar-notifications.html#CodeStarNotifications.Client.delete_notification_rule)
-        [Show boto3-stubs documentation](./client.md#delete-notification-rule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codestar-notifications.html#CodeStarNotifications.Client.delete_notification_rule)
+        [Show boto3-stubs documentation](./client.md#delete_notification_rule)
         """
 
     def delete_target(self, TargetAddress: str, ForceUnsubscribeAll: bool = None) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codestar-notifications.html#CodeStarNotifications.Client.delete_target)
-        [Show boto3-stubs documentation](./client.md#delete-target)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codestar-notifications.html#CodeStarNotifications.Client.delete_target)
+        [Show boto3-stubs documentation](./client.md#delete_target)
         """
 
     def describe_notification_rule(self, Arn: str) -> DescribeNotificationRuleResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codestar-notifications.html#CodeStarNotifications.Client.describe_notification_rule)
-        [Show boto3-stubs documentation](./client.md#describe-notification-rule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codestar-notifications.html#CodeStarNotifications.Client.describe_notification_rule)
+        [Show boto3-stubs documentation](./client.md#describe_notification_rule)
         """
 
     def generate_presigned_url(
@@ -127,8 +122,8 @@ class CodeStarNotificationsClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codestar-notifications.html#CodeStarNotifications.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](./client.md#generate-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codestar-notifications.html#CodeStarNotifications.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
     def list_event_types(
@@ -138,8 +133,8 @@ class CodeStarNotificationsClient:
         MaxResults: int = None,
     ) -> ListEventTypesResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codestar-notifications.html#CodeStarNotifications.Client.list_event_types)
-        [Show boto3-stubs documentation](./client.md#list-event-types)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codestar-notifications.html#CodeStarNotifications.Client.list_event_types)
+        [Show boto3-stubs documentation](./client.md#list_event_types)
         """
 
     def list_notification_rules(
@@ -149,14 +144,14 @@ class CodeStarNotificationsClient:
         MaxResults: int = None,
     ) -> ListNotificationRulesResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codestar-notifications.html#CodeStarNotifications.Client.list_notification_rules)
-        [Show boto3-stubs documentation](./client.md#list-notification-rules)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codestar-notifications.html#CodeStarNotifications.Client.list_notification_rules)
+        [Show boto3-stubs documentation](./client.md#list_notification_rules)
         """
 
     def list_tags_for_resource(self, Arn: str) -> ListTagsForResourceResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codestar-notifications.html#CodeStarNotifications.Client.list_tags_for_resource)
-        [Show boto3-stubs documentation](./client.md#list-tags-for-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codestar-notifications.html#CodeStarNotifications.Client.list_tags_for_resource)
+        [Show boto3-stubs documentation](./client.md#list_tags_for_resource)
         """
 
     def list_targets(
@@ -166,54 +161,54 @@ class CodeStarNotificationsClient:
         MaxResults: int = None,
     ) -> ListTargetsResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codestar-notifications.html#CodeStarNotifications.Client.list_targets)
-        [Show boto3-stubs documentation](./client.md#list-targets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codestar-notifications.html#CodeStarNotifications.Client.list_targets)
+        [Show boto3-stubs documentation](./client.md#list_targets)
         """
 
     def subscribe(
         self, Arn: str, Target: TargetTypeDef, ClientRequestToken: str = None
     ) -> SubscribeResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codestar-notifications.html#CodeStarNotifications.Client.subscribe)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codestar-notifications.html#CodeStarNotifications.Client.subscribe)
         [Show boto3-stubs documentation](./client.md#subscribe)
         """
 
     def tag_resource(self, Arn: str, Tags: Dict[str, str]) -> TagResourceResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codestar-notifications.html#CodeStarNotifications.Client.tag_resource)
-        [Show boto3-stubs documentation](./client.md#tag-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codestar-notifications.html#CodeStarNotifications.Client.tag_resource)
+        [Show boto3-stubs documentation](./client.md#tag_resource)
         """
 
     def unsubscribe(self, Arn: str, TargetAddress: str) -> UnsubscribeResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codestar-notifications.html#CodeStarNotifications.Client.unsubscribe)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codestar-notifications.html#CodeStarNotifications.Client.unsubscribe)
         [Show boto3-stubs documentation](./client.md#unsubscribe)
         """
 
     def untag_resource(self, Arn: str, TagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codestar-notifications.html#CodeStarNotifications.Client.untag_resource)
-        [Show boto3-stubs documentation](./client.md#untag-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codestar-notifications.html#CodeStarNotifications.Client.untag_resource)
+        [Show boto3-stubs documentation](./client.md#untag_resource)
         """
 
     def update_notification_rule(
         self,
         Arn: str,
         Name: str = None,
-        Status: NotificationRuleStatus = None,
+        Status: NotificationRuleStatusType = None,
         EventTypeIds: List[str] = None,
         Targets: List[TargetTypeDef] = None,
-        DetailType: DetailType = None,
+        DetailType: DetailTypeType = None,
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codestar-notifications.html#CodeStarNotifications.Client.update_notification_rule)
-        [Show boto3-stubs documentation](./client.md#update-notification-rule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codestar-notifications.html#CodeStarNotifications.Client.update_notification_rule)
+        [Show boto3-stubs documentation](./client.md#update_notification_rule)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_event_types"]) -> ListEventTypesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListEventTypes)[Show boto3-stubs documentation](./paginators.md#listeventtypespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListEventTypes)[Show boto3-stubs documentation](./paginators.md#listeventtypespaginator)
         """
 
     @overload
@@ -221,11 +216,11 @@ class CodeStarNotificationsClient:
         self, operation_name: Literal["list_notification_rules"]
     ) -> ListNotificationRulesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListNotificationRules)[Show boto3-stubs documentation](./paginators.md#listnotificationrulespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListNotificationRules)[Show boto3-stubs documentation](./paginators.md#listnotificationrulespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_targets"]) -> ListTargetsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListTargets)[Show boto3-stubs documentation](./paginators.md#listtargetspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListTargets)[Show boto3-stubs documentation](./paginators.md#listtargetspaginator)
         """
